@@ -11,6 +11,7 @@ class Transition(object):
 		"""Creates an instance of Transition"""
 
 		self.__next_transitions = None
+		self.__parent_transition = None
 		self.__percent_partial_save = None
 		self.__data = None
 		self.__next_field_value = None
@@ -19,6 +20,8 @@ class Transition(object):
 		self.__id = None
 		self.__fields = None
 		self.__criteria_message = None
+		self.__type = None
+		self.__execution_time = None
 		self.__key_modified = dict()
 
 	def get_next_transitions(self):
@@ -45,6 +48,35 @@ class Transition(object):
 		self.__next_transitions = next_transitions
 		self.__key_modified['next_transitions'] = 1
 
+	def get_parent_transition(self):
+		"""
+		The method to get the parent_transition
+
+		Returns:
+			Transition: An instance of Transition
+		"""
+
+		return self.__parent_transition
+
+	def set_parent_transition(self, parent_transition):
+		"""
+		The method to set the value to parent_transition
+
+		Parameters:
+			parent_transition (Transition) : An instance of Transition
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.blue_print.transition import Transition
+		except Exception:
+			from .transition import Transition
+
+		if parent_transition is not None and not isinstance(parent_transition, Transition):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: parent_transition EXPECTED TYPE: Transition', None, None)
+		
+		self.__parent_transition = parent_transition
+		self.__key_modified['parent_transition'] = 1
+
 	def get_percent_partial_save(self):
 		"""
 		The method to get the percent_partial_save
@@ -242,6 +274,56 @@ class Transition(object):
 		self.__criteria_message = criteria_message
 		self.__key_modified['criteria_message'] = 1
 
+	def get_type(self):
+		"""
+		The method to get the type
+
+		Returns:
+			string: A string representing the type
+		"""
+
+		return self.__type
+
+	def set_type(self, type):
+		"""
+		The method to set the value to type
+
+		Parameters:
+			type (string) : A string representing the type
+		"""
+
+		if type is not None and not isinstance(type, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: type EXPECTED TYPE: str', None, None)
+		
+		self.__type = type
+		self.__key_modified['type'] = 1
+
+	def get_execution_time(self):
+		"""
+		The method to get the execution_time
+
+		Returns:
+			datetime: An instance of datetime
+		"""
+
+		return self.__execution_time
+
+	def set_execution_time(self, execution_time):
+		"""
+		The method to set the value to execution_time
+
+		Parameters:
+			execution_time (datetime) : An instance of datetime
+		"""
+
+		from datetime import datetime
+
+		if execution_time is not None and not isinstance(execution_time, datetime):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: execution_time EXPECTED TYPE: datetime', None, None)
+		
+		self.__execution_time = execution_time
+		self.__key_modified['execution_time'] = 1
+
 	def is_key_modified(self, key):
 		"""
 		The method to check if the user has modified the given key
