@@ -14,6 +14,7 @@ class MultiSelectLookup(object):
 		self.__linking_module = None
 		self.__lookup_apiname = None
 		self.__api_name = None
+		self.__connected_module = None
 		self.__connectedlookup_apiname = None
 		self.__id = None
 		self.__key_modified = dict()
@@ -114,6 +115,30 @@ class MultiSelectLookup(object):
 		self.__api_name = api_name
 		self.__key_modified['api_name'] = 1
 
+	def get_connected_module(self):
+		"""
+		The method to get the connected_module
+
+		Returns:
+			string: A string representing the connected_module
+		"""
+
+		return self.__connected_module
+
+	def set_connected_module(self, connected_module):
+		"""
+		The method to set the value to connected_module
+
+		Parameters:
+			connected_module (string) : A string representing the connected_module
+		"""
+
+		if connected_module is not None and not isinstance(connected_module, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: connected_module EXPECTED TYPE: str', None, None)
+		
+		self.__connected_module = connected_module
+		self.__key_modified['connected_module'] = 1
+
 	def get_connectedlookup_apiname(self):
 		"""
 		The method to get the connectedlookup_apiname
