@@ -21,7 +21,7 @@ class ViewType(object):
 		The method to get the view
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the view
 		"""
 
 		return self.__view
@@ -45,7 +45,7 @@ class ViewType(object):
 		The method to get the edit
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the edit
 		"""
 
 		return self.__edit
@@ -69,7 +69,7 @@ class ViewType(object):
 		The method to get the create
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the create
 		"""
 
 		return self.__create
@@ -93,7 +93,7 @@ class ViewType(object):
 		The method to get the quick_create
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the quick_create
 		"""
 
 		return self.__quick_create
@@ -120,7 +120,7 @@ class ViewType(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
