@@ -21,12 +21,15 @@ class Module(object):
 		self.__modified_time = None
 		self.__plural_label = None
 		self.__presence_sub_menu = None
+		self.__isblueprintsupported = None
 		self.__triggers_supported = None
 		self.__id = None
 		self.__related_list_properties = None
 		self.__properties = None
+		self.__on_demand_properties = None
 		self.__per_page = None
 		self.__visibility = None
+		self.__visible = None
 		self.__convertable = None
 		self.__editable = None
 		self.__emailtemplate_support = None
@@ -61,7 +64,7 @@ class Module(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -85,7 +88,7 @@ class Module(object):
 		The method to get the global_search_supported
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the global_search_supported
 		"""
 
 		return self.__global_search_supported
@@ -109,7 +112,7 @@ class Module(object):
 		The method to get the kanban_view
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the kanban_view
 		"""
 
 		return self.__kanban_view
@@ -133,7 +136,7 @@ class Module(object):
 		The method to get the deletable
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the deletable
 		"""
 
 		return self.__deletable
@@ -157,7 +160,7 @@ class Module(object):
 		The method to get the description
 
 		Returns:
-			string: A string value
+			string: A string representing the description
 		"""
 
 		return self.__description
@@ -181,7 +184,7 @@ class Module(object):
 		The method to get the creatable
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the creatable
 		"""
 
 		return self.__creatable
@@ -205,7 +208,7 @@ class Module(object):
 		The method to get the filter_status
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the filter_status
 		"""
 
 		return self.__filter_status
@@ -229,7 +232,7 @@ class Module(object):
 		The method to get the inventory_template_supported
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the inventory_template_supported
 		"""
 
 		return self.__inventory_template_supported
@@ -279,7 +282,7 @@ class Module(object):
 		The method to get the plural_label
 
 		Returns:
-			string: A string value
+			string: A string representing the plural_label
 		"""
 
 		return self.__plural_label
@@ -303,7 +306,7 @@ class Module(object):
 		The method to get the presence_sub_menu
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the presence_sub_menu
 		"""
 
 		return self.__presence_sub_menu
@@ -322,12 +325,36 @@ class Module(object):
 		self.__presence_sub_menu = presence_sub_menu
 		self.__key_modified['presence_sub_menu'] = 1
 
+	def get_isblueprintsupported(self):
+		"""
+		The method to get the isblueprintsupported
+
+		Returns:
+			bool: A bool representing the isblueprintsupported
+		"""
+
+		return self.__isblueprintsupported
+
+	def set_isblueprintsupported(self, isblueprintsupported):
+		"""
+		The method to set the value to isblueprintsupported
+
+		Parameters:
+			isblueprintsupported (bool) : A bool representing the isblueprintsupported
+		"""
+
+		if isblueprintsupported is not None and not isinstance(isblueprintsupported, bool):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: isblueprintsupported EXPECTED TYPE: bool', None, None)
+		
+		self.__isblueprintsupported = isblueprintsupported
+		self.__key_modified['isBlueprintSupported'] = 1
+
 	def get_triggers_supported(self):
 		"""
 		The method to get the triggers_supported
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the triggers_supported
 		"""
 
 		return self.__triggers_supported
@@ -351,7 +378,7 @@ class Module(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -423,12 +450,36 @@ class Module(object):
 		self.__properties = properties
 		self.__key_modified['$properties'] = 1
 
+	def get_on_demand_properties(self):
+		"""
+		The method to get the on_demand_properties
+
+		Returns:
+			list: An instance of list
+		"""
+
+		return self.__on_demand_properties
+
+	def set_on_demand_properties(self, on_demand_properties):
+		"""
+		The method to set the value to on_demand_properties
+
+		Parameters:
+			on_demand_properties (list) : An instance of list
+		"""
+
+		if on_demand_properties is not None and not isinstance(on_demand_properties, list):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: on_demand_properties EXPECTED TYPE: list', None, None)
+		
+		self.__on_demand_properties = on_demand_properties
+		self.__key_modified['$on_demand_properties'] = 1
+
 	def get_per_page(self):
 		"""
 		The method to get the per_page
 
 		Returns:
-			int: A int value
+			int: An int representing the per_page
 		"""
 
 		return self.__per_page
@@ -452,7 +503,7 @@ class Module(object):
 		The method to get the visibility
 
 		Returns:
-			int: A int value
+			int: An int representing the visibility
 		"""
 
 		return self.__visibility
@@ -471,12 +522,36 @@ class Module(object):
 		self.__visibility = visibility
 		self.__key_modified['visibility'] = 1
 
+	def get_visible(self):
+		"""
+		The method to get the visible
+
+		Returns:
+			bool: A bool representing the visible
+		"""
+
+		return self.__visible
+
+	def set_visible(self, visible):
+		"""
+		The method to set the value to visible
+
+		Parameters:
+			visible (bool) : A bool representing the visible
+		"""
+
+		if visible is not None and not isinstance(visible, bool):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: visible EXPECTED TYPE: bool', None, None)
+		
+		self.__visible = visible
+		self.__key_modified['visible'] = 1
+
 	def get_convertable(self):
 		"""
 		The method to get the convertable
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the convertable
 		"""
 
 		return self.__convertable
@@ -500,7 +575,7 @@ class Module(object):
 		The method to get the editable
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the editable
 		"""
 
 		return self.__editable
@@ -524,7 +599,7 @@ class Module(object):
 		The method to get the emailtemplate_support
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the emailtemplate_support
 		"""
 
 		return self.__emailtemplate_support
@@ -572,7 +647,7 @@ class Module(object):
 		The method to get the filter_supported
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the filter_supported
 		"""
 
 		return self.__filter_supported
@@ -596,7 +671,7 @@ class Module(object):
 		The method to get the display_field
 
 		Returns:
-			string: A string value
+			string: A string representing the display_field
 		"""
 
 		return self.__display_field
@@ -644,7 +719,7 @@ class Module(object):
 		The method to get the kanban_view_supported
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the kanban_view_supported
 		"""
 
 		return self.__kanban_view_supported
@@ -668,7 +743,7 @@ class Module(object):
 		The method to get the show_as_tab
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the show_as_tab
 		"""
 
 		return self.__show_as_tab
@@ -692,7 +767,7 @@ class Module(object):
 		The method to get the web_link
 
 		Returns:
-			string: A string value
+			string: A string representing the web_link
 		"""
 
 		return self.__web_link
@@ -716,7 +791,7 @@ class Module(object):
 		The method to get the sequence_number
 
 		Returns:
-			int: A int value
+			int: An int representing the sequence_number
 		"""
 
 		return self.__sequence_number
@@ -740,7 +815,7 @@ class Module(object):
 		The method to get the singular_label
 
 		Returns:
-			string: A string value
+			string: A string representing the singular_label
 		"""
 
 		return self.__singular_label
@@ -764,7 +839,7 @@ class Module(object):
 		The method to get the viewable
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the viewable
 		"""
 
 		return self.__viewable
@@ -788,7 +863,7 @@ class Module(object):
 		The method to get the api_supported
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the api_supported
 		"""
 
 		return self.__api_supported
@@ -812,7 +887,7 @@ class Module(object):
 		The method to get the api_name
 
 		Returns:
-			string: A string value
+			string: A string representing the api_name
 		"""
 
 		return self.__api_name
@@ -836,7 +911,7 @@ class Module(object):
 		The method to get the quick_create
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the quick_create
 		"""
 
 		return self.__quick_create
@@ -913,7 +988,7 @@ class Module(object):
 		The method to get the feeds_required
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the feeds_required
 		"""
 
 		return self.__feeds_required
@@ -937,7 +1012,7 @@ class Module(object):
 		The method to get the scoring_supported
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the scoring_supported
 		"""
 
 		return self.__scoring_supported
@@ -961,7 +1036,7 @@ class Module(object):
 		The method to get the webform_supported
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the webform_supported
 		"""
 
 		return self.__webform_supported
@@ -1009,7 +1084,7 @@ class Module(object):
 		The method to get the module_name
 
 		Returns:
-			string: A string value
+			string: A string representing the module_name
 		"""
 
 		return self.__module_name
@@ -1033,7 +1108,7 @@ class Module(object):
 		The method to get the business_card_field_limit
 
 		Returns:
-			int: A int value
+			int: An int representing the business_card_field_limit
 		"""
 
 		return self.__business_card_field_limit
@@ -1147,7 +1222,7 @@ class Module(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
