@@ -4,7 +4,7 @@ from .note import Note
 from .response_handler import ResponseHandler
 from .action_response import ActionResponse
 from .success_response import SuccessResponse
-from .notes_operations import NotesOperations, GetNotesParam, GetNotesHeader, DeleteNotesParam
+from .notes_operations import NotesOperations, GetNotesParam, GetNotesHeader, DeleteNotesParam, GetNoteParam, GetNoteHeader
 from .response_wrapper import ResponseWrapper
 from .body_wrapper import BodyWrapper
 from .action_handler import ActionHandler
