@@ -21,7 +21,7 @@ class Comment(object):
 		The method to get the commented_by
 
 		Returns:
-			string: A string value
+			string: A string representing the commented_by
 		"""
 
 		return self.__commented_by
@@ -71,7 +71,7 @@ class Comment(object):
 		The method to get the comment_content
 
 		Returns:
-			string: A string value
+			string: A string representing the comment_content
 		"""
 
 		return self.__comment_content
@@ -95,7 +95,7 @@ class Comment(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -122,7 +122,7 @@ class Comment(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
