@@ -36,7 +36,7 @@ class RelatedListsOperations(object):
 
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/related_lists'
+		api_path = api_path + '/crm/v2.1/settings/related_lists'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
@@ -66,7 +66,7 @@ class RelatedListsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/related_lists/'
+		api_path = api_path + '/crm/v2.1/settings/related_lists/'
 		api_path = api_path + str(id)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
