@@ -19,7 +19,7 @@ class Info(object):
 		The method to get the count
 
 		Returns:
-			int: A int value
+			int: An int representing the count
 		"""
 
 		return self.__count
@@ -43,7 +43,7 @@ class Info(object):
 		The method to get the allowed_count
 
 		Returns:
-			int: A int value
+			int: An int representing the allowed_count
 		"""
 
 		return self.__allowed_count
@@ -70,7 +70,7 @@ class Info(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
