@@ -22,7 +22,7 @@ class Tax(object):
 		The method to get the display_label
 
 		Returns:
-			string: A string value
+			string: A string representing the display_label
 		"""
 
 		return self.__display_label
@@ -46,7 +46,7 @@ class Tax(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -70,7 +70,7 @@ class Tax(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -94,7 +94,7 @@ class Tax(object):
 		The method to get the value
 
 		Returns:
-			float: A float value
+			float: A float representing the value
 		"""
 
 		return self.__value
@@ -118,7 +118,7 @@ class Tax(object):
 		The method to get the sequence_number
 
 		Returns:
-			int: A int value
+			int: An int representing the sequence_number
 		"""
 
 		return self.__sequence_number
@@ -145,7 +145,7 @@ class Tax(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
