@@ -19,7 +19,7 @@ class User(Record):
 		The method to get the country
 
 		Returns:
-			string: A string value
+			string: A string representing the country
 		"""
 
 		return self.get_key_value('country')
@@ -98,7 +98,7 @@ class User(Record):
 		The method to get the signature
 
 		Returns:
-			string: A string value
+			string: A string representing the signature
 		"""
 
 		return self.get_key_value('signature')
@@ -121,7 +121,7 @@ class User(Record):
 		The method to get the city
 
 		Returns:
-			string: A string value
+			string: A string representing the city
 		"""
 
 		return self.get_key_value('city')
@@ -144,7 +144,7 @@ class User(Record):
 		The method to get the name_format
 
 		Returns:
-			string: A string value
+			string: A string representing the name_format
 		"""
 
 		return self.get_key_value('name_format')
@@ -167,7 +167,7 @@ class User(Record):
 		The method to get the personal_account
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the personal_account
 		"""
 
 		return self.get_key_value('personal_account')
@@ -190,7 +190,7 @@ class User(Record):
 		The method to get the default_tab_group
 
 		Returns:
-			string: A string value
+			string: A string representing the default_tab_group
 		"""
 
 		return self.get_key_value('default_tab_group')
@@ -213,7 +213,7 @@ class User(Record):
 		The method to get the language
 
 		Returns:
-			string: A string value
+			string: A string representing the language
 		"""
 
 		return self.get_key_value('language')
@@ -236,7 +236,7 @@ class User(Record):
 		The method to get the locale
 
 		Returns:
-			string: A string value
+			string: A string representing the locale
 		"""
 
 		return self.get_key_value('locale')
@@ -259,7 +259,7 @@ class User(Record):
 		The method to get the microsoft
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the microsoft
 		"""
 
 		return self.get_key_value('microsoft')
@@ -282,7 +282,7 @@ class User(Record):
 		The method to get the isonline
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the isonline
 		"""
 
 		return self.get_key_value('Isonline')
@@ -305,7 +305,7 @@ class User(Record):
 		The method to get the street
 
 		Returns:
-			string: A string value
+			string: A string representing the street
 		"""
 
 		return self.get_key_value('street')
@@ -328,7 +328,7 @@ class User(Record):
 		The method to get the currency
 
 		Returns:
-			string: A string value
+			string: A string representing the currency
 		"""
 
 		return self.get_key_value('Currency')
@@ -351,7 +351,7 @@ class User(Record):
 		The method to get the alias
 
 		Returns:
-			string: A string value
+			string: A string representing the alias
 		"""
 
 		return self.get_key_value('alias')
@@ -402,7 +402,7 @@ class User(Record):
 		The method to get the state
 
 		Returns:
-			string: A string value
+			string: A string representing the state
 		"""
 
 		return self.get_key_value('state')
@@ -425,7 +425,7 @@ class User(Record):
 		The method to get the fax
 
 		Returns:
-			string: A string value
+			string: A string representing the fax
 		"""
 
 		return self.get_key_value('fax')
@@ -448,7 +448,7 @@ class User(Record):
 		The method to get the country_locale
 
 		Returns:
-			string: A string value
+			string: A string representing the country_locale
 		"""
 
 		return self.get_key_value('country_locale')
@@ -471,7 +471,7 @@ class User(Record):
 		The method to get the first_name
 
 		Returns:
-			string: A string value
+			string: A string representing the first_name
 		"""
 
 		return self.get_key_value('first_name')
@@ -494,7 +494,7 @@ class User(Record):
 		The method to get the email
 
 		Returns:
-			string: A string value
+			string: A string representing the email
 		"""
 
 		return self.get_key_value('email')
@@ -545,7 +545,7 @@ class User(Record):
 		The method to get the decimal_separator
 
 		Returns:
-			string: A string value
+			string: A string representing the decimal_separator
 		"""
 
 		return self.get_key_value('decimal_separator')
@@ -568,7 +568,7 @@ class User(Record):
 		The method to get the zip
 
 		Returns:
-			string: A string value
+			string: A string representing the zip
 		"""
 
 		return self.get_key_value('zip')
@@ -591,7 +591,7 @@ class User(Record):
 		The method to get the website
 
 		Returns:
-			string: A string value
+			string: A string representing the website
 		"""
 
 		return self.get_key_value('website')
@@ -614,7 +614,7 @@ class User(Record):
 		The method to get the time_format
 
 		Returns:
-			string: A string value
+			string: A string representing the time_format
 		"""
 
 		return self.get_key_value('time_format')
@@ -637,7 +637,7 @@ class User(Record):
 		The method to get the offset
 
 		Returns:
-			int: A int value
+			int: An int representing the offset
 		"""
 
 		return self.get_key_value('offset')
@@ -688,7 +688,7 @@ class User(Record):
 		The method to get the mobile
 
 		Returns:
-			string: A string value
+			string: A string representing the mobile
 		"""
 
 		return self.get_key_value('mobile')
@@ -711,7 +711,7 @@ class User(Record):
 		The method to get the last_name
 
 		Returns:
-			string: A string value
+			string: A string representing the last_name
 		"""
 
 		return self.get_key_value('last_name')
@@ -734,7 +734,7 @@ class User(Record):
 		The method to get the time_zone
 
 		Returns:
-			string: A string value
+			string: A string representing the time_zone
 		"""
 
 		return self.get_key_value('time_zone')
@@ -757,7 +757,7 @@ class User(Record):
 		The method to get the zuid
 
 		Returns:
-			string: A string value
+			string: A string representing the zuid
 		"""
 
 		return self.get_key_value('zuid')
@@ -780,7 +780,7 @@ class User(Record):
 		The method to get the confirm
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the confirm
 		"""
 
 		return self.get_key_value('confirm')
@@ -803,7 +803,7 @@ class User(Record):
 		The method to get the full_name
 
 		Returns:
-			string: A string value
+			string: A string representing the full_name
 		"""
 
 		return self.get_key_value('full_name')
@@ -849,7 +849,7 @@ class User(Record):
 		The method to get the phone
 
 		Returns:
-			string: A string value
+			string: A string representing the phone
 		"""
 
 		return self.get_key_value('phone')
@@ -872,7 +872,7 @@ class User(Record):
 		The method to get the dob
 
 		Returns:
-			string: A string value
+			string: A string representing the dob
 		"""
 
 		return self.get_key_value('dob')
@@ -895,7 +895,7 @@ class User(Record):
 		The method to get the date_format
 
 		Returns:
-			string: A string value
+			string: A string representing the date_format
 		"""
 
 		return self.get_key_value('date_format')
@@ -918,7 +918,7 @@ class User(Record):
 		The method to get the status
 
 		Returns:
-			string: A string value
+			string: A string representing the status
 		"""
 
 		return self.get_key_value('status')
@@ -941,7 +941,7 @@ class User(Record):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.get_key_value('name')
